import { GraphQLSchema } from 'graphql';
import { SilverbackResolver } from '../types';
/**
 * Extract Object types with @sourceFrom directives.
 *
 * Returns a map of type names to source package and function name tuples.
 */
export declare function extractSourceMapping(schema: GraphQLSchema): Record<string, string>;
/**
 * Extract fields types with @resolveBy directives.
 *
 * Returns a nested map of type names, field names, package and function name tuples.
 */
export declare function extractResolverMapping(schema: GraphQLSchema, directives: Record<string, Function>): Record<string, Record<string, [string, Record<string, unknown>][]>>;
/**
 * Extract a list of all union types.
 */
export declare function extractUnions(schema: GraphQLSchema): string[];
/**
 * Extract a list of all interface types.
 */
export declare function extractInterfaces(schema: GraphQLSchema): string[];
/**
 * Clean up a schema string and remove everything that could confuse Gatsby.
 */
export declare function cleanSchema(schema: string): string;
export declare function processDirectiveArguments(parent: unknown, args: Record<string, any>, spec: Record<string, unknown>): {
    [k: string]: any;
};
export declare function buildResolver(config: Array<[string, Record<string, unknown>]>, directives: Record<string, Function>): SilverbackResolver;
